@@ -23,10 +23,11 @@ get_port <- function() {
 #' @details See \url{https://github.com/vnijs/gitgadget} for documentation
 #'
 #' @param port Port to use for the app
+#' @param host Host ip to use
 #' @param launch.browser Launch app in viewer (browsers) or only show the URL
 #'
 #' @export
-gitgadget <- function(port = get_port(), launch.browser = TRUE) {
+gitgadget <- function(port = get_port(), host = "127.0.0.1", launch.browser = TRUE) {
   gitgadget_dir <- system.file(package = "gitgadget")
   source(file.path(gitgadget_dir, "app/init.R"), local = TRUE)
   source(file.path(gitgadget_dir, "app/gitgadget_ui.R"), local = TRUE)
@@ -50,7 +51,7 @@ gitgadget <- function(port = get_port(), launch.browser = TRUE) {
   if (rstudioapi::isAvailable() && launch.browser) {
     runGadget(shinyApp(ui, server), port = port, viewer = shiny::paneViewer(minHeight = 725))
   } else {
-    runApp(shinyApp(ui, server), port = port, launch.browser = launch.browser)
+    runApp(shinyApp(ui, server), port = port, host = host, launch.browser = launch.browser)
   }
 }
 
@@ -76,7 +77,9 @@ gitgadget_url <- function() {
 #' @export
 gitgadget_callr <- function() {
   port <- get_port()
-  callr::r_bg(function(port) { gitgadget::gitgadget(port = port) }, args = list(port), user_profile = TRUE)
+  callr::r_bg(function(port) {
+    gitgadget::gitgadget(port = port)
+  }, args = list(port), user_profile = TRUE)
   Sys.sleep(1)
   getOption("viewer")(paste0("http://localhost:", port, "/"))
-}
+}
\ No newline at end of file
